# Ãô¸Ð¹Ø¼ü×Ö
from typing import List

KEYWORDS: List[str] = ["password", "passwd", "token", "authorized_token", "access_token",
                "security_token", "username", "user_name", "uname", "login", "logout", "ip", "ip_address", "ip_add",
                "domain", "internal_domain", "realm"]
